@@ -15,7 +15,14 @@ _is_bond()
 
 bonding_pre_start()
 {
-	local x= s= slaves="$(_get_array "slaves_${IFVAR}")" 
+	local x= s= n= slaves= primary=
+
+	slaves="$(_get_array "slaves_${IFVAR}")"
+	unset slaves_${IFVAR}
+
+	eval primary="\$primary_${IFVAR}"
+	unset primary_${IFVAR}
+
 
 	[ -z "${slaves}" ] && return 0
 
@@ -43,9 +50,12 @@ bonding_pre_start()
 	# Nice and dynamic :)
 	for x in /sys/class/net/"${IFACE}"/bonding/*; do
 		[ -f "${x}" ] || continue
-		eval s=\$${x##*/}_${IFVAR}
+		n=${x##*/}
+		eval s=\$${n}_${IFVAR}
 		if [ -n "${s}" ]; then
-			echo "${s}" >"${x}"
+			einfo "Setting ${n}: ${s}"
+			echo "${s}" >"${x}" || \
+			eerror "Failed to configure $n (${n}_${IFVAR})"
 		fi
 	done
 
@@ -72,6 +82,11 @@ bonding_pre_start()
 	# finally add in slaves
 	eoutdent
 	if [ -d /sys/class/net ]; then
+		if [ -n "${primary}" ]; then
+			echo "+${primary}" >/sys/class/net/"${IFACE}"/bonding/slaves
+			echo "${primary}" >/sys/class/net/"${IFACE}"/bonding/primary
+			slaves="${slaves/${primary}/}"
+		fi
 		for s in ${slaves}; do
 			echo "+${s}" >/sys/class/net/"${IFACE}"/bonding/slaves
 		done
@@ -117,6 +132,12 @@ bonding_stop()
 	done
 	)
 
+	_down
+
+	if [ -d /sys/class/net ]; then
+		echo "-${IFACE}" > /sys/class/net/bonding_masters
+	fi
+
 	eend 0
 	return 0
 }
